@@ -738,7 +738,7 @@ def pretraining_numpy(arr, batch_size, shuffle=False, max_obs=100,
 
 def pretraining_data(data, batch_size, shuffle=False, max_obs=100,
                         msk_frac=0.2, rnd_frac=0.1, same_frac=0.1, mode=None):
-    modes = ["clf"]
+    modes = [None, "clf"]
     if mode not in modes:
         raise ValueError(f"Mode {mode} is not defined. Please select among {modes}")
     
